Struct jupiter::ig::symbols::SymbolTable

source ·
pub struct SymbolTable { /* private fields */ }
Used to resolve and lookup symbols.

Implementations

Creates a new and empty symbol table.

Example
let table = SymbolTable::new();

assert_eq!(table.len(), 0);

Tries to resolve the given string into an existing Symbol.

If no symbol with the given name is known, None is returned. If a new symbol should be created instead, use find_or_create.

Example
let mut table = SymbolTable::new();

let symbol = table.find_or_create("Test").unwrap();

assert_eq!(table.resolve("Test").unwrap(), symbol);
assert_eq!(table.resolve("Unknown").is_none(), true);

Resolve the given string into a new or an existing Symbol.

If no symbol should be created if the given name is unknown, use resolve.

Errors

This will return an error if the internal symbol table overflows (if there are more than std::i32::MAX - 2 symbols).

Example
let mut table = SymbolTable::new();

let symbol = table.find_or_create("Test").unwrap();
assert_eq!(table.resolve("Test").unwrap(), symbol);

Retrieves the name of the given Symbol.

Examples
let mut table = SymbolTable::new();

let symbol = table.find_or_create("Test").unwrap();

// A known symbol can be looked up...
assert_eq!(table.lookup(symbol), "Test");

// An unknown symbol is simply translated to ""
assert_eq!(table.lookup(1024), "");

Determines the number of known symbols in the table.

Examples
let mut table = SymbolTable::new();

// The same symbol is only added once to a table...
let symbol = table.find_or_create("Test").unwrap();
let symbol1 = table.find_or_create("Test").unwrap();
assert_eq!(symbol, symbol1);

// ..therefore the table size is 1.
assert_eq!(table.len(), 1);

// If we add another symbol...
table.find_or_create("Test 2").unwrap();

// ...the size grows to 2.
assert_eq!(table.len(), 2);

Determines if the symbol table is empty.

Examples
let mut table = SymbolTable::new();

assert_eq!(table.is_empty(), true);
let _ = table.find_or_create("Test").unwrap();
assert_eq!(table.is_empty(), false);

Estimates the allocated memory required to represent the symbol table.

Note that this is only an approximation as some inner types to not reveal their size.

Example
let mut table = SymbolTable::new();

table.find_or_create("Hello").unwrap();
table.find_or_create("World").unwrap();

println!("{}", table.allocated_size());