pub enum BackgroundEvent {
FileListUpdated(Vec<RepositoryFile>),
FileEvent(FileEvent),
EpochCounter(i64),
}Expand description
Represents events which are sent back from the background worker to the frontend.
Variants
FileListUpdated(Vec<RepositoryFile>)
Signals that a new list of repository files has been determined.
FileEvent(FileEvent)
Signals that a file has most probably changed.
EpochCounter(i64)
Completes the roundtrip of a BackgroundCommand::EmitEpochCounter`