pub struct Repository { /* private fields */ }Expand description
A repository is the central instance which connects the several actors together.
Note that a repository itself has nearly no public API. Rather, one or more custom Loaders can be registered which are then invoked once an appropriate file changes.
Implementations
Sourceimpl Repository
impl Repository
Sourcepub fn register_loader(&self, name: String, loader: Arc<dyn Loader>)
pub fn register_loader(&self, name: String, loader: Arc<dyn Loader>)
Registers a loader.
A loader can be referenced by a loader descriptor and will subsequently be invoked once the reference file or the loader descriptor itself changes.